--
-- PostgreSQL database dump
--

SET client_encoding = 'SQL_ASCII';
SET check_function_bodies = false;

SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 4 (OID 2200)
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
GRANT ALL ON SCHEMA public TO PUBLIC;


SET SESSION AUTHORIZATION 'postgres';

SET search_path = public, pg_catalog;

--
-- TOC entry 5 (OID 26604)
-- Name: id; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE id
    INCREMENT BY 1
    MAXVALUE 2147483647
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 6 (OID 26606)
-- Name: makemodel; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE makemodel (
    parts_id integer,
    name text
);


--
-- TOC entry 7 (OID 26611)
-- Name: gl; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE gl (
    id integer DEFAULT nextval('id'::text),
    source text,
    description text,
    transdate date DEFAULT ('now'::text)::date,
    employee_id integer,
    batch character varying(50),
    project character varying(50),
    subb character varying(50),
    transtype text,
    transno text,
    subtransno text
);


--
-- TOC entry 8 (OID 26618)
-- Name: chart; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE chart (
    id integer DEFAULT nextval('id'::text),
    accno text NOT NULL,
    description text,
    charttype character(1) DEFAULT 'A'::bpchar,
    category character(1),
    link text,
    gifi_accno text
);


--
-- TOC entry 9 (OID 26625)
-- Name: gifi; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE gifi (
    accno text,
    description text
);


--
-- TOC entry 10 (OID 26630)
-- Name: defaults; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE "defaults" (
    inventory_accno_id integer,
    income_accno_id integer,
    expense_accno_id integer,
    fxgain_accno_id integer,
    fxloss_accno_id integer,
    invnumber text,
    sonumber text,
    yearend character varying(5),
    weightunit character varying(5),
    businessnumber text,
    "version" character varying(8),
    curr text,
    closedto date,
    revtrans boolean DEFAULT false,
    ponumber text,
    adnumber text,
    debitnumber text,
    debitnumbercus text,
    creditnumber text,
    creditnumbercus text,
    orid text,
    fy text,
    pyid text
);


--
-- TOC entry 11 (OID 26636)
-- Name: acc_trans; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE acc_trans (
    trans_id integer,
    chart_id integer,
    amount double precision,
    transdate date DEFAULT ('now'::text)::date,
    source text,
    cleared boolean DEFAULT false,
    fx_transaction boolean DEFAULT false,
    project character varying(255),
    sub character varying(255)
);


--
-- TOC entry 12 (OID 26644)
-- Name: invoice; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE invoice (
    id integer DEFAULT nextval('id'::text),
    trans_id integer,
    parts_id integer,
    description text,
    qty real,
    allocated real,
    sellprice double precision,
    fxsellprice double precision,
    discount real,
    assemblyitem boolean DEFAULT false,
    unit character varying(5),
    delivery_date text,
    lastcost double precision,
    remark2 text,
    part_ordnumber text,
    taxincluded boolean,
    tax double precision
);


--
-- TOC entry 13 (OID 26651)
-- Name: vendor; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE vendor (
    id integer DEFAULT nextval('id'::text),
    name character varying(255),
    addr1 character varying(255),
    addr2 character varying(255),
    addr3 character varying(255),
    addr4 character varying(255),
    contact character varying(255),
    phone character varying(100),
    fax character varying(100),
    email text,
    notes text,
    terms smallint DEFAULT 0,
    taxincluded boolean,
    vendornumber text,
    locationcode character varying(255),
    salesperson character varying(255),
    vendorcode text,
    debitlimit double precision
);


--
-- TOC entry 14 (OID 26660)
-- Name: customer; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE customer (
    id integer DEFAULT nextval('id'::text),
    name character varying(255),
    addr1 character varying(255),
    addr2 character varying(255),
    addr3 character varying(255),
    addr4 character varying(255),
    contact character varying(255),
    phone character varying(100),
    fax character varying(100),
    email text,
    notes text,
    discount real,
    taxincluded boolean,
    creditlimit double precision DEFAULT 0,
    terms smallint DEFAULT 0,
    shiptoname character varying(255),
    shiptoaddr1 character varying(255),
    shiptoaddr2 character varying(255),
    shiptoaddr3 character varying(255),
    shiptoaddr4 character varying(255),
    shiptocontact character varying(255),
    shiptophone character varying(100),
    shiptofax character varying(100),
    shiptoemail text,
    customernumber text,
    locationcode character varying(255),
    salesperson character varying(255),
    customercode text
);


--
-- TOC entry 15 (OID 26670)
-- Name: parts; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE parts (
    id integer DEFAULT nextval('id'::text),
    partnumber text,
    description text,
    unit character varying(5),
    listprice double precision,
    sellprice double precision,
    lastcost double precision,
    priceupdate date DEFAULT ('now'::text)::date,
    weight real,
    onhand real DEFAULT 0,
    notes text,
    makemodel boolean DEFAULT false,
    assembly boolean DEFAULT false,
    alternate boolean DEFAULT false,
    rop real,
    inventory_accno_id integer,
    income_accno_id integer,
    expense_accno_id integer,
    bin text,
    obsolete boolean DEFAULT false,
    avgcost double precision,
    combo boolean,
    taxincluded boolean
);


--
-- TOC entry 16 (OID 26682)
-- Name: assembly; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE assembly (
    id integer,
    parts_id integer,
    qty double precision
);


--
-- TOC entry 17 (OID 26684)
-- Name: ar; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE ar (
    id integer DEFAULT nextval('id'::text),
    invnumber text,
    transdate date DEFAULT ('now'::text)::date,
    customer_id integer,
    taxincluded boolean,
    amount double precision,
    netamount double precision,
    paid double precision,
    datepaid date,
    duedate date,
    invoice boolean DEFAULT false,
    shippingpoint text,
    terms smallint DEFAULT 0,
    notes text,
    curr character(3),
    ordnumber text,
    employee_id integer,
    salesperson character varying(255),
    batch character varying(50),
    project character varying(50),
    subb character varying(50),
    transtype text,
    transno text,
    subtransno text,
    rowcount integer,
    invoiceto text,
    member text,
    kp text
);


--
-- TOC entry 18 (OID 26693)
-- Name: ap; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE ap (
    id integer DEFAULT nextval('id'::text),
    invnumber text,
    transdate date DEFAULT ('now'::text)::date,
    vendor_id integer,
    taxincluded boolean DEFAULT false,
    amount double precision,
    netamount double precision,
    paid double precision,
    datepaid date,
    duedate date,
    invoice boolean DEFAULT false,
    ordnumber text,
    curr character(3),
    notes text,
    employee_id integer,
    donumber text,
    terms smallint,
    batch character varying(50),
    project character varying(50),
    subb character varying(50),
    transtype text,
    transno text,
    subtransno text,
    rowcount integer,
    desc_1 text,
    desc_2 text,
    desc_3 text,
    desc_4 text,
    desc_5 text,
    qty_1 double precision,
    qty_2 double precision,
    qty_3 double precision,
    qty_4 double precision,
    qty_5 double precision,
    amount_1 double precision,
    amount_2 double precision,
    amount_3 double precision,
    amount_4 double precision,
    amount_5 double precision
);


--
-- TOC entry 19 (OID 26702)
-- Name: partstax; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE partstax (
    parts_id integer,
    chart_id integer
);


--
-- TOC entry 20 (OID 26704)
-- Name: tax; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE tax (
    chart_id integer,
    rate double precision,
    taxnumber text
);


--
-- TOC entry 21 (OID 26709)
-- Name: customertax; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE customertax (
    customer_id integer,
    chart_id integer
);


--
-- TOC entry 22 (OID 26711)
-- Name: vendortax; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE vendortax (
    vendor_id integer,
    chart_id integer
);


--
-- TOC entry 23 (OID 26713)
-- Name: oe; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE oe (
    id integer DEFAULT nextval('id'::text),
    ordnumber text,
    transdate date DEFAULT ('now'::text)::date,
    vendor_id integer,
    customer_id integer,
    amount double precision,
    netamount double precision,
    reqdate date,
    taxincluded boolean,
    shippingpoint text,
    notes text,
    curr character(3),
    employee_id integer,
    transtype character varying(100),
    yourref text,
    status integer
);


--
-- TOC entry 24 (OID 26720)
-- Name: orderitems; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE orderitems (
    trans_id integer,
    parts_id integer,
    description text,
    qty real,
    sellprice double precision,
    discount real,
    unit character varying(5),
    delivery_date text,
    remark2 text,
    tax double precision
);


--
-- TOC entry 25 (OID 26725)
-- Name: exchangerate; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE exchangerate (
    curr character(3),
    transdate date,
    buy double precision,
    sell double precision
);


--
-- TOC entry 26 (OID 26727)
-- Name: employee; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE employee (
    id integer DEFAULT nextval('id'::text),
    login text,
    name character varying(35),
    addr1 character varying(35),
    addr2 character varying(35),
    addr3 character varying(35),
    addr4 character varying(35),
    workphone character varying(20),
    homephone character varying(20),
    startdate date DEFAULT ('now'::text)::date,
    enddate date,
    notes text
);


--
-- TOC entry 27 (OID 26734)
-- Name: adjust; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE adjust (
    id integer DEFAULT nextval('id'::text),
    adnumber text,
    transdate date,
    employee_id integer,
    notes text,
    "type" character varying(255)
);


--
-- TOC entry 28 (OID 26740)
-- Name: adjustitems; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE adjustitems (
    trans_id integer,
    parts_id integer,
    description text,
    qty double precision,
    sellprice double precision,
    discount double precision,
    unit character varying(5),
    lastcost double precision
);


--
-- TOC entry 29 (OID 26745)
-- Name: debitnote; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE debitnote (
    id integer DEFAULT nextval('id'::text),
    ordnumber text,
    transdate date DEFAULT ('now'::text)::date,
    vendor_id integer,
    customer_id integer,
    amount double precision,
    netamount double precision,
    reqdate date,
    taxincluded boolean,
    shippingpoint text,
    notes text,
    invoice boolean,
    invnumber text,
    curr character(3),
    employee_id integer,
    batch character varying(50),
    project character varying(50),
    subb character varying(50),
    transtype text,
    transno text,
    subtransno text,
    salesperson text
);


--
-- TOC entry 30 (OID 26752)
-- Name: debititems; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE debititems (
    trans_id integer,
    parts_id integer,
    description text,
    qty real,
    sellprice double precision,
    discount real,
    unit character varying(5)
);


--
-- TOC entry 31 (OID 26757)
-- Name: creditnote; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE creditnote (
    id integer DEFAULT nextval('id'::text),
    ordnumber text,
    transdate date DEFAULT ('now'::text)::date,
    vendor_id integer,
    customer_id integer,
    amount double precision,
    netamount double precision,
    reqdate date,
    taxincluded boolean,
    shippingpoint text,
    notes text,
    curr character(3),
    invoice boolean,
    invnumber text,
    employee_id integer,
    batch character varying(50),
    project character varying(50),
    subb character varying(50),
    transtype text,
    transno text,
    subtransno text,
    salesperson text
);


--
-- TOC entry 32 (OID 26764)
-- Name: credititems; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE credititems (
    trans_id integer,
    parts_id integer,
    description text,
    qty real,
    sellprice double precision,
    discount real,
    unit character varying(5)
);


--
-- TOC entry 33 (OID 26769)
-- Name: oreceipt; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE oreceipt (
    id integer DEFAULT nextval('id'::text),
    source text,
    chart_id integer,
    ar_chart_id integer,
    employee_id integer,
    orid text,
    amount double precision,
    transdate date,
    customernumber character varying(255),
    curr character varying(3),
    exchangerate real,
    batch character varying(50),
    transtype text,
    transno text,
    subtransno text
);


--
-- TOC entry 34 (OID 26775)
-- Name: oreceipt_items; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE oreceipt_items (
    trans_id integer,
    ar_chart_id integer,
    status text,
    due real,
    amount real
);


--
-- TOC entry 35 (OID 26782)
-- Name: receipt; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW receipt AS
    SELECT acc_trans.trans_id, ar.customer_id, customer.name, ar.invnumber, ar.transdate, acc_trans.transdate AS paydate, acc_trans.source, acc_trans.chart_id, chart.accno, chart.description, (acc_trans.amount * (-1)::double precision) AS amount FROM ar, acc_trans, chart WHERE ((((ar.id = acc_trans.trans_id) AND (chart.id = acc_trans.chart_id)) AND (chart.link ~~ '%AP_paid%'::text)) AND (customer.id = ar.customer_id));


--
-- TOC entry 36 (OID 26783)
-- Name: gp; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE gp (
    id integer DEFAULT nextval('id'::text),
    transtype text,
    batch text,
    "type" integer,
    chart_id integer,
    employee_id integer,
    transdate date,
    project character varying(255),
    sub character varying(255)
);


--
-- TOC entry 37 (OID 26789)
-- Name: gp_trans; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE gp_trans (
    id integer,
    transno text,
    subtransno text,
    chart_id integer,
    amount double precision,
    description text,
    source text,
    transdate date,
    sub text,
    proj text
);


--
-- TOC entry 38 (OID 26794)
-- Name: ou; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE ou (
    id integer DEFAULT nextval('id'::text),
    transtype text,
    batch text,
    employee_id integer,
    project character varying(255),
    sub character varying(255)
);


--
-- TOC entry 39 (OID 26800)
-- Name: ou_trans; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE ou_trans (
    id integer,
    transno text,
    subtransno text,
    chart_id integer,
    amount double precision,
    description text,
    source text,
    transdate date,
    sub text
);


--
-- TOC entry 40 (OID 26817)
-- Name: invoice_listing1; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW invoice_listing1 AS
    SELECT ar.project, ar.subb, ar.id, ar.invnumber, ar.transdate, parts.partnumber, invoice.description, invoice.qty, invoice.fxsellprice AS price, (invoice.qty * invoice.fxsellprice) AS subtotal, invoice.parts_id, ar.customer_id, ar.employee_id, customer.customernumber, customer.name, employee.login, parts.weight, invoice.delivery_date, invoice.remark2, parts.onhand, invoice.part_ordnumber AS ordnumber FROM invoice, ar, parts, customer WHERE ((((invoice.trans_id = ar.id) AND (invoice.parts_id = parts.id)) AND (ar.customer_id = customer.id)) AND (ar.employee_id = employee.id)) ORDER BY ar.invnumber;


--
-- TOC entry 41 (OID 26821)
-- Name: invoice_listing2; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW invoice_listing2 AS
    SELECT DISTINCT ON (acc_trans.trans_id) acc_trans.chart_id, chart.accno, acc_trans.trans_id FROM acc_trans, chart WHERE (((acc_trans.amount > (0)::double precision) AND (chart.id = acc_trans.chart_id)) AND (chart.link = 'AR'::text)) ORDER BY acc_trans.trans_id;


--
-- TOC entry 42 (OID 26824)
-- Name: invoice_listing; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW invoice_listing AS
    SELECT v1.project, v1.subb, v1.id, v1.invnumber, v1.ordnumber, delivery_date, remark2, v1.transdate, v1.partnumber, v1.description, v1.qty, v1.price, v1.subtotal AS subtotal1, v1.parts_id, v1.customer_id, v1.employee_id, v1.customernumber AS accno, v1.name AS customer, v1.login, v1.weight, (v1.weight * v1.onhand) AS qtykg, v2.chart_id, v2.trans_id FROM (invoice_listing1 v1 LEFT JOIN (SELECT invoice_listing2.chart_id, invoice_listing2.accno, invoice_listing2.trans_id FROM invoice_listing2) v2 ON ((v1.id = v2.trans_id)));


--
-- TOC entry 43 (OID 26828)
-- Name: vendor_listing1; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW vendor_listing1 AS
    SELECT ap.project, ap.subb, ap.id, ap.invnumber, ap.transdate, parts.partnumber, invoice.description, invoice.qty, invoice.fxsellprice AS price, (invoice.qty * invoice.fxsellprice) AS subtotal, invoice.parts_id, ap.vendor_id, ap.employee_id, vendor.vendornumber, vendor.name, employee.login, parts.weight, parts.onhand, invoice.part_ordnumber AS ordnumber, invoice.delivery_date, invoice.remark2 FROM invoice, ap, parts, vendor WHERE ((((invoice.trans_id = ap.id) AND (invoice.parts_id = parts.id)) AND (ap.vendor_id = vendor.id)) AND (ap.employee_id = employee.id)) ORDER BY ap.invnumber;


--
-- TOC entry 44 (OID 26832)
-- Name: vendor_listing2; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW vendor_listing2 AS
    SELECT DISTINCT ON (acc_trans.trans_id) acc_trans.chart_id, chart.accno, acc_trans.trans_id FROM acc_trans, chart WHERE (((acc_trans.amount > (0)::double precision) AND (chart.id = acc_trans.chart_id)) AND (chart.link = 'AP'::text)) ORDER BY acc_trans.trans_id;


--
-- TOC entry 45 (OID 26835)
-- Name: vendor_listing; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW vendor_listing AS
    SELECT v1.project, v1.subb, v1.id, v1.invnumber, v1.ordnumber, v1.transdate, v1.partnumber, v1.description, v1.qty, v1.price, v1.subtotal AS subtotal1, v1.parts_id, v1.vendor_id, v1.employee_id, v1.vendornumber AS accno, v1.name AS customer, v1.login, v1.weight, (v1.weight * v1.onhand) AS qtykg, v2.chart_id, v2.trans_id, delivery_date, remark2 FROM (vendor_listing1 v1 LEFT JOIN (SELECT vendor_listing2.chart_id, vendor_listing2.accno, vendor_listing2.trans_id FROM vendor_listing2) v2 ON ((v1.id = v2.trans_id)));


--
-- TOC entry 46 (OID 26839)
-- Name: sales_listing1; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW sales_listing1 AS
    SELECT oe.id, orderitems.delivery_date, orderitems.remark2, oe.ordnumber, oe.transdate, parts.partnumber, orderitems.description, orderitems.qty, orderitems.sellprice AS price, (orderitems.qty * orderitems.sellprice) AS subtotal, orderitems.parts_id, oe.customer_id, oe.employee_id, customer.customernumber, customer.name, employee.login, parts.weight, parts.onhand FROM orderitems, oe, parts, customer WHERE ((((orderitems.trans_id = oe.id) AND (orderitems.parts_id = parts.id)) AND (oe.customer_id = customer.id)) AND (oe.employee_id = employee.id)) ORDER BY oe.ordnumber;


--
-- TOC entry 47 (OID 26843)
-- Name: sales_listing2; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW sales_listing2 AS
    SELECT DISTINCT ON (acc_trans.trans_id) acc_trans.chart_id, chart.accno, acc_trans.trans_id FROM acc_trans, chart WHERE (((acc_trans.amount > (0)::double precision) AND (chart.id = acc_trans.chart_id)) AND (chart.link = 'AR'::text)) ORDER BY acc_trans.trans_id;


--
-- TOC entry 48 (OID 26846)
-- Name: sales_listing; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW sales_listing AS
    SELECT v1.id, delivery_date, remark2, v1.ordnumber AS invnumber, v1.transdate, v1.partnumber, v1.description, v1.qty, v1.price, v1.subtotal AS subtotal1, v1.parts_id, v1.customer_id, v1.employee_id, v1.customernumber AS accno, v1.name AS customer, v1.login, v1.weight, (v1.weight * v1.onhand) AS qtykg, v2.chart_id, v2.trans_id FROM (sales_listing1 v1 LEFT JOIN (SELECT sales_listing2.chart_id, sales_listing2.accno, sales_listing2.trans_id FROM sales_listing2) v2 ON ((v1.id = v2.trans_id)));


--
-- TOC entry 49 (OID 26850)
-- Name: purchase_listing1; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW purchase_listing1 AS
    SELECT oe.id, orderitems.delivery_date, orderitems.remark2, oe.ordnumber, oe.transdate, parts.partnumber, orderitems.description, orderitems.qty, orderitems.sellprice AS price, (orderitems.qty * orderitems.sellprice) AS subtotal, orderitems.parts_id, oe.vendor_id, oe.employee_id, vendor.vendornumber, vendor.name, employee.login, parts.weight, parts.onhand FROM orderitems, oe, parts, vendor WHERE ((((orderitems.trans_id = oe.id) AND (orderitems.parts_id = parts.id)) AND (oe.vendor_id = vendor.id)) AND (oe.employee_id = employee.id)) ORDER BY oe.ordnumber;


--
-- TOC entry 50 (OID 26854)
-- Name: purchase_listing2; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW purchase_listing2 AS
    SELECT DISTINCT ON (acc_trans.trans_id) acc_trans.chart_id, chart.accno, acc_trans.trans_id FROM acc_trans, chart WHERE (((acc_trans.amount > (0)::double precision) AND (chart.id = acc_trans.chart_id)) AND (chart.link = 'AR'::text)) ORDER BY acc_trans.trans_id;


--
-- TOC entry 51 (OID 26857)
-- Name: purchase_listing; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW purchase_listing AS
    SELECT v1.id, delivery_date, remark2, v1.ordnumber AS invnumber, v1.transdate, v1.partnumber, v1.description, v1.qty, v1.price, v1.subtotal AS subtotal1, v1.parts_id, v1.vendor_id AS customer_id, v1.employee_id, v1.vendornumber, v1.name AS customer, v1.login, v1.weight, (v1.weight * v1.onhand) AS qtykg, v2.chart_id, v2.accno, v2.trans_id FROM (purchase_listing1 v1 LEFT JOIN (SELECT purchase_listing2.chart_id, purchase_listing2.accno, purchase_listing2.trans_id FROM purchase_listing2) v2 ON ((v1.id = v2.trans_id)));


--
-- TOC entry 52 (OID 26859)
-- Name: payment; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE payment (
    id integer DEFAULT nextval('id'::text),
    source text,
    chart_id integer,
    ap_chart_id integer,
    employee_id integer,
    pyid text,
    amount double precision,
    transdate date,
    vendornumber character varying(255),
    curr character varying(3),
    exchangerate real,
    batch character varying(50),
    transtype text,
    transno text,
    subtransno text
);


--
-- TOC entry 53 (OID 26865)
-- Name: payment_items; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE payment_items (
    trans_id integer,
    ap_chart_id integer,
    status text,
    due real,
    amount real
);


--
-- TOC entry 54 (OID 26872)
-- Name: payment1; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW payment1 AS
    SELECT acc_trans.trans_id, ap.vendor_id, vendor.name, ap.invnumber, ap.transdate, acc_trans.transdate AS paydate, acc_trans.source, acc_trans.chart_id, chart.accno, chart.description, (acc_trans.amount * (-1)::double precision) AS amount FROM ap, acc_trans, chart WHERE ((((ap.id = acc_trans.trans_id) AND (chart.id = acc_trans.chart_id)) AND (chart.link ~~ '%AP_paid%'::text)) AND (vendor.id = ap.vendor_id));


--
-- TOC entry 55 (OID 26875)
-- Name: sl; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW sl AS
    (((SELECT 'adjust.pl' AS module, adjust.adnumber, adjust.transdate, adjustitems.parts_id, parts.partnumber, adjustitems.description, 0 AS sin, 0 AS sout, adjustitems.qty AS adjust, adjustitems.lastcost FROM adjust, adjustitems, parts WHERE ((adjust.id = adjustitems.trans_id) AND (parts.id = adjustitems.parts_id)) UNION ALL SELECT 'is.pl' AS module, ar.invnumber AS adnumber, ar.transdate, invoice.parts_id, parts.partnumber, invoice.description, 0 AS sin, invoice.qty AS sout, 0 AS adjust, invoice.sellprice AS lastcost FROM ar, invoice, parts WHERE ((ar.id = invoice.trans_id) AND (parts.id = invoice.parts_id))) UNION ALL SELECT 'ir.pl' AS module, ap.invnumber AS adnumber, ap.transdate, invoice.parts_id, parts.partnumber, invoice.description, (invoice.qty * (-1)::double precision) AS sin, 0 AS sout, 0 AS adjust, invoice.sellprice AS lastcost FROM ap, invoice, parts WHERE ((ap.id = invoice.trans_id) AND (parts.id = invoice.parts_id))) UNION ALL SELECT 'creditnote.pl' AS module, creditnote.ordnumber AS adnumber, creditnote.transdate, credititems.parts_id, parts.partnumber, credititems.description, credititems.qty AS sin, 0 AS sout, 0 AS adjust, credititems.sellprice AS lastcost FROM creditnote, credititems, parts WHERE (((creditnote.id = credititems.trans_id) AND (parts.id = credititems.parts_id)) AND (creditnote.vendor_id = 0))) UNION ALL SELECT 'creditnote.pl' AS module, creditnote.ordnumber AS adnumber, creditnote.transdate, credititems.parts_id, parts.partnumber, credititems.description, 0 AS sin, credititems.qty AS sout, 0 AS adjust, credititems.sellprice AS lastcost FROM creditnote, credititems, parts WHERE (((creditnote.id = credititems.trans_id) AND (parts.id = credititems.parts_id)) AND (creditnote.customer_id = 0));


--
-- TOC entry 56 (OID 26877)
-- Name: combo; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE combo (
    id integer,
    parts_id integer
);


SET SESSION AUTHORIZATION 'root';

--
-- TOC entry 57 (OID 112799)
-- Name: statement2; Type: VIEW; Schema: public; Owner: root
--

CREATE VIEW statement2 AS
    (((((((SELECT gl.id, 'gl' AS "type", false AS invoice, gl.source, gl.description, acc_trans.transdate, acc_trans.amount, chart.accno, chart.description AS accdesc, chart.id AS chart_id, chart.gifi_accno, gl.transtype, gl.batch, gl.transno, gl.subtransno, acc_trans.project, acc_trans.sub FROM gl, acc_trans, chart WHERE (((1 = 1) AND (acc_trans.chart_id = chart.id)) AND (gl.id = acc_trans.trans_id)) UNION ALL SELECT ar.id, 'ar' AS "type", ar.invoice, ar.invnumber AS source, ar.notes AS description, acc_trans.transdate, acc_trans.amount, chart.accno, chart.description AS accdesc, chart.id AS chart_id, chart.gifi_accno, ar.transtype, ar.batch, ar.transno, ar.subtransno, acc_trans.project, acc_trans.sub FROM ar, acc_trans, chart, customer WHERE ((((1 = 1) AND (acc_trans.chart_id = chart.id)) AND (ar.customer_id = customer.id)) AND (ar.id = acc_trans.trans_id))) UNION ALL SELECT ap.id, 'ap' AS "type", ap.invoice, ap.invnumber AS source, ap.notes AS description, acc_trans.transdate, acc_trans.amount, chart.accno, chart.description AS accdesc, chart.id AS chart_id, chart.gifi_accno, ap.transtype, ap.batch, ap.transno, ap.subtransno, acc_trans.project, acc_trans.sub FROM ap, acc_trans, chart, vendor WHERE ((((1 = 1) AND (acc_trans.chart_id = chart.id)) AND (ap.vendor_id = vendor.id)) AND (ap.id = acc_trans.trans_id))) UNION ALL SELECT gp.id, 'gp' AS "type", false AS invoice, gp_trans.source, gp_trans.description, gp_trans.transdate, gp_trans.amount, chart.accno, chart.description AS accdesc, chart.id AS chart_id, chart.gifi_accno, gp.transtype, gp.batch, gp_trans.transno, gp_trans.subtransno, gp.project, gp.sub FROM gp, chart, gp_trans WHERE (((1 = 1) AND (gp_trans.chart_id = chart.id)) AND (gp.id = gp_trans.id))) UNION ALL SELECT ou.id, 'ou' AS "type", false AS invoice, ou_trans.source, ou_trans.description, ou_trans.transdate, ou_trans.amount, chart.accno, chart.description AS accdesc, chart.id AS chart_id, chart.gifi_accno, ou.transtype, ou.batch, ou_trans.transno, ou_trans.subtransno, ou.project, ou.sub FROM ou, chart, ou_trans WHERE (((1 = 1) AND (ou_trans.chart_id = chart.id)) AND (ou.id = ou_trans.id))) UNION ALL SELECT ar.id, 'dn' AS "type", ar.invoice, ar.ordnumber AS source, customer.name AS description, acc_trans.transdate, acc_trans.amount, chart.accno, chart.description AS accdesc, chart.id AS chart_id, chart.gifi_accno, ar.transtype, ar.batch, ar.transno, ar.subtransno, acc_trans.project, acc_trans.sub FROM debitnote ar, acc_trans, chart, customer WHERE ((((1 = 1) AND (acc_trans.chart_id = chart.id)) AND (ar.customer_id = customer.id)) AND (ar.id = acc_trans.trans_id))) UNION ALL SELECT ap.id, 'dn1' AS "type", ap.invoice, ap.ordnumber AS source, vendor.name AS description, acc_trans.transdate, acc_trans.amount, chart.accno, chart.description AS accdesc, chart.id AS chart_id, chart.gifi_accno, ap.transtype, ap.batch, ap.transno, ap.subtransno, acc_trans.project, acc_trans.sub FROM debitnote ap, acc_trans, chart, vendor WHERE ((((1 = 1) AND (acc_trans.chart_id = chart.id)) AND (ap.vendor_id = vendor.id)) AND (ap.id = acc_trans.trans_id))) UNION ALL SELECT ar.id, 'cn' AS "type", ar.invoice, ar.ordnumber AS source, ar.notes AS description, acc_trans.transdate, acc_trans.amount, chart.accno, chart.description AS accdesc, chart.id AS chart_id, chart.gifi_accno, ar.transtype, ar.batch, ar.transno, ar.subtransno, acc_trans.project, acc_trans.sub FROM creditnote ar, acc_trans, chart, customer WHERE ((((1 = 1) AND (acc_trans.chart_id = chart.id)) AND (ar.customer_id = customer.id)) AND (ar.id = acc_trans.trans_id))) UNION ALL SELECT ap.id, 'cn1' AS "type", ap.invoice, ap.ordnumber AS source, ap.notes AS description, acc_trans.transdate, acc_trans.amount, chart.accno, chart.description AS accdesc, chart.id AS chart_id, chart.gifi_accno, ap.transtype, ap.batch, ap.transno, ap.subtransno, acc_trans.project, acc_trans.sub FROM creditnote ap, acc_trans, chart, vendor WHERE ((((1 = 1) AND (acc_trans.chart_id = chart.id)) AND (ap.vendor_id = vendor.id)) AND (ap.id = acc_trans.trans_id)) ORDER BY 6, 12, 13, 14, 15, 8, 9, 16, 17;


SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 71 (OID 26953)
-- Name: acc_trans_trans_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX acc_trans_trans_id_key ON acc_trans USING btree (trans_id);


--
-- TOC entry 70 (OID 26954)
-- Name: acc_trans_chart_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX acc_trans_chart_id_key ON acc_trans USING btree (chart_id);


--
-- TOC entry 72 (OID 26955)
-- Name: acc_trans_transdate_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX acc_trans_transdate_key ON acc_trans USING btree (transdate);


--
-- TOC entry 94 (OID 26956)
-- Name: ap_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ap_id_key ON ap USING btree (id);


--
-- TOC entry 97 (OID 26957)
-- Name: ap_transdate_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ap_transdate_key ON ap USING btree (transdate);


--
-- TOC entry 95 (OID 26958)
-- Name: ap_invnumber_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ap_invnumber_key ON ap USING btree (lower(invnumber));


--
-- TOC entry 96 (OID 26959)
-- Name: ap_ordnumber_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ap_ordnumber_key ON ap USING btree (lower(ordnumber));


--
-- TOC entry 98 (OID 26960)
-- Name: ap_vendor_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ap_vendor_id_key ON ap USING btree (vendor_id);


--
-- TOC entry 93 (OID 26961)
-- Name: ap_employee_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ap_employee_id_key ON ap USING btree (employee_id);


--
-- TOC entry 89 (OID 26962)
-- Name: ar_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ar_id_key ON ar USING btree (id);


--
-- TOC entry 92 (OID 26963)
-- Name: ar_transdate_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ar_transdate_key ON ar USING btree (transdate);


--
-- TOC entry 90 (OID 26964)
-- Name: ar_invnumber_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ar_invnumber_key ON ar USING btree (lower(invnumber));


--
-- TOC entry 91 (OID 26965)
-- Name: ar_ordnumber_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ar_ordnumber_key ON ar USING btree (lower(ordnumber));


--
-- TOC entry 87 (OID 26966)
-- Name: ar_customer_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ar_customer_id_key ON ar USING btree (customer_id);


--
-- TOC entry 88 (OID 26967)
-- Name: ar_employee_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX ar_employee_id_key ON ar USING btree (employee_id);


--
-- TOC entry 86 (OID 26968)
-- Name: assembly_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX assembly_id_key ON assembly USING btree (id);


--
-- TOC entry 67 (OID 26969)
-- Name: chart_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX chart_id_key ON chart USING btree (id);


--
-- TOC entry 64 (OID 26970)
-- Name: chart_accno_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX chart_accno_key ON chart USING btree (accno);


--
-- TOC entry 65 (OID 26971)
-- Name: chart_category_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX chart_category_key ON chart USING btree (category);


--
-- TOC entry 68 (OID 26972)
-- Name: chart_link_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX chart_link_key ON chart USING btree (link);


--
-- TOC entry 66 (OID 26973)
-- Name: chart_gifi_accno_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX chart_gifi_accno_key ON chart USING btree (gifi_accno);


--
-- TOC entry 81 (OID 26974)
-- Name: customer_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX customer_id_key ON customer USING btree (id);


--
-- TOC entry 100 (OID 26975)
-- Name: customer_customer_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX customer_customer_id_key ON customertax USING btree (customer_id);


--
-- TOC entry 82 (OID 26976)
-- Name: customer_name_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX customer_name_key ON customer USING btree (name);


--
-- TOC entry 79 (OID 26977)
-- Name: customer_contact_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX customer_contact_key ON customer USING btree (contact);


--
-- TOC entry 108 (OID 26978)
-- Name: employee_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX employee_id_key ON employee USING btree (id);


--
-- TOC entry 109 (OID 26979)
-- Name: employee_login_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX employee_login_key ON employee USING btree (login);


--
-- TOC entry 110 (OID 26980)
-- Name: employee_name_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX employee_name_key ON employee USING btree (name);


--
-- TOC entry 107 (OID 26981)
-- Name: exchangerate_ct_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX exchangerate_ct_key ON exchangerate USING btree (curr, transdate);


--
-- TOC entry 69 (OID 26982)
-- Name: gifi_accno_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX gifi_accno_key ON gifi USING btree (accno);


--
-- TOC entry 61 (OID 26983)
-- Name: gl_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gl_id_key ON gl USING btree (id);


--
-- TOC entry 63 (OID 26984)
-- Name: gl_transdate_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gl_transdate_key ON gl USING btree (transdate);


--
-- TOC entry 62 (OID 26985)
-- Name: gl_source_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gl_source_key ON gl USING btree (lower(source));


--
-- TOC entry 59 (OID 26986)
-- Name: gl_description_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gl_description_key ON gl USING btree (lower(description));


--
-- TOC entry 60 (OID 26987)
-- Name: gl_employee_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gl_employee_id_key ON gl USING btree (employee_id);


--
-- TOC entry 73 (OID 26988)
-- Name: invoice_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX invoice_id_key ON invoice USING btree (id);


--
-- TOC entry 74 (OID 26989)
-- Name: invoice_trans_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX invoice_trans_id_key ON invoice USING btree (trans_id);


--
-- TOC entry 58 (OID 26990)
-- Name: makemodel_parts_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX makemodel_parts_id_key ON makemodel USING btree (parts_id);


--
-- TOC entry 103 (OID 26991)
-- Name: oe_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX oe_id_key ON oe USING btree (id);


--
-- TOC entry 105 (OID 26992)
-- Name: oe_transdate_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX oe_transdate_key ON oe USING btree (transdate);


--
-- TOC entry 104 (OID 26993)
-- Name: oe_ordnumber_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX oe_ordnumber_key ON oe USING btree (lower(ordnumber));


--
-- TOC entry 102 (OID 26994)
-- Name: oe_employee_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX oe_employee_id_key ON oe USING btree (employee_id);


--
-- TOC entry 106 (OID 26995)
-- Name: orderitems_trans_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX orderitems_trans_id_key ON orderitems USING btree (trans_id);


--
-- TOC entry 84 (OID 26996)
-- Name: parts_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX parts_id_key ON parts USING btree (id);


--
-- TOC entry 85 (OID 26997)
-- Name: parts_partnumber_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX parts_partnumber_key ON parts USING btree (lower(partnumber));


--
-- TOC entry 83 (OID 26998)
-- Name: parts_description_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX parts_description_key ON parts USING btree (lower(description));


--
-- TOC entry 99 (OID 26999)
-- Name: partstax_parts_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX partstax_parts_id_key ON partstax USING btree (parts_id);


--
-- TOC entry 76 (OID 27000)
-- Name: vendor_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX vendor_id_key ON vendor USING btree (id);


--
-- TOC entry 77 (OID 27001)
-- Name: vendor_name_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX vendor_name_key ON vendor USING btree (name);


--
-- TOC entry 75 (OID 27002)
-- Name: vendor_contact_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX vendor_contact_key ON vendor USING btree (contact);


--
-- TOC entry 101 (OID 27003)
-- Name: vendortax_vendor_id_key; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX vendortax_vendor_id_key ON vendortax USING btree (vendor_id);


--
-- TOC entry 78 (OID 26658)
-- Name: vendor_vendornumber_key; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY vendor
    ADD CONSTRAINT vendor_vendornumber_key UNIQUE (vendornumber);


--
-- TOC entry 80 (OID 26668)
-- Name: customer_customernumber_key; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY customer
    ADD CONSTRAINT customer_customernumber_key UNIQUE (customernumber);


--
-- TOC entry 3 (OID 2200)
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA public IS 'Standard public schema';


